@@ -10,7 +10,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * SCCS: @(#) tclMacPort.h 1.61 96/07/25 13:29:02
+ * SCCS: @(#) tclMacPort.h 1.56 96/04/12 09:41:51
  */
 
 #ifndef _MACPORT
@@ -20,17 +20,12 @@
 #include "tcl.h"
 #endif
 
-#include "tclErrno.h"
-
 /* Includes */
 #ifdef THINK_C
-	/*
-	 * The Symantic C code has not been tested
-	 * and probably will not work.
-	 */
 #   include <pascal.h>
 #   include <posix.h>
 #   include <string.h>
+#   include <errno.h>
 #   include <fcntl.h>
 #   include <pwd.h>
 #   include <sys/param.h>
@@ -38,47 +33,27 @@
 #   include <sys/stat.h>
 #   include <unistd.h>
 #elif defined(__MWERKS__)
-#   include <time.h>
-#   include <unistd.h>
-#   include <fcntl.h>
+#   include <sys/types.h>
 
 /*
- * MetroWerks stat.h file is rather weak.  The defines
- * after the include are needed to fill in the missing
- * defines.
+ * We must explicitly include both errno.h and
+ * sys/errno.h.  sys/errno.h is defined in CWGUSI
  */
-#   include <stat.h>
-#   ifndef S_IFIFO
-#	define   S_IFIFO	0x0100
-#   endif
-#   ifndef S_IFBLK
-#	define   S_IFBLK	0x0600
-#   endif
-#   ifndef S_ISLNK
-#	define   S_ISLNK(m)	(((m)&(S_IFMT)) == (S_IFLNK))
-#   endif
-#   ifndef S_ISSOCK
-#	define   S_ISSOCK(m)	(((m)&(S_IFMT)) == (S_IFSOCK))
-#   endif
+#   include "errno.h"
+#   include "sys/errno.h"
 
+#   include <unistd.h>
+#   include <sys/unistd.h>
+#   include <sys/fcntl.h>
+#   include <sys/stat.h>
 #   define isatty(arg) 1
 
-/* 
- * Defines used by access function.  This function is provided
- * by Mac Tcl as the function TclMacAccess.
- */
- 
-#   define	F_OK		0	/* test for existence of file */
-#   define	X_OK		0x01	/* test for execute or search permission */
-#   define	W_OK		0x02	/* test for write permission */
-#   define	R_OK		0x04	/* test for read permission */
-
 #endif
 
 /*
  * waitpid doesn't work on a Mac - the following makes
  * Tcl compile without errors.  These would normally
- * be defined in sys/wait.h on UNIX systems.
+ * be defined in sys/wait.h
  */
 #ifdef NO_SYS_WAIT_H
 #   define WNOHANG 1
@@ -104,6 +79,24 @@
 #define TclWriteFile(file, shouldBlock, buf, toWrite) (-1)
 #define TclSeekFile(file, offset, whence) (-1)
 
+/*
+ * The following macro defines the type of the mask arguments to
+ * select:
+ */
+
+#ifndef NO_FD_SET
+#   define SELECT_MASK fd_set
+#else
+#   ifndef _AIX
+	typedef long fd_mask;
+#   endif
+#   if defined(_IBMR2)
+#	define SELECT_MASK void
+#   else
+#	define SELECT_MASK int
+#   endif
+#endif
+
 /*
  * Define "NBBY" (number of bits per byte) if it's not already defined.
  */
@@ -112,23 +105,51 @@
 #   define NBBY 8
 #endif
 
+/*
+ * The following macro defines the number of fd_masks in an fd_set:
+ */
+
+#if !defined(howmany)
+#   define howmany(x, y) (((x)+((y)-1))/(y))
+#endif
+#ifdef NFDBITS
+#   define MASK_SIZE howmany(FD_SETSIZE, NFDBITS)
+#else
+#   define MASK_SIZE howmany(OPEN_MAX, NBBY*sizeof(fd_mask))
+#endif
+
 /*
  * These functions always return dummy values on Mac.
  */
-#ifndef geteuid
-#   define geteuid() 1
+#define geteuid() 1
+#define getpid() -1
+
+/*
+ * Macros to do string compares.  They pre-check the first character
+ * before checking if the strings are equal.
+ */
+
+#define STREQU(str1, str2) \
+        (((str1) [0] == (str2) [0]) && (strcmp (str1, str2) == 0))
+#define STRNEQU(str1, str2, cnt) \
+        (((str1) [0] == (str2) [0]) && (strncmp (str1, str2, cnt) == 0))
+
+#ifndef FALSE
+#define FALSE 0
 #endif
-#ifndef getpid
-#   define getpid() -1
+
+#ifndef TRUE
+#define TRUE 1
 #endif
 
 #define NO_SYS_ERRLIST
-#define WAIT_STATUS_TYPE int
 
 /*
  * Make sure that MAXPATHLEN is defined.
  */
 
+#define WAIT_STATUS_TYPE pid_t
+
 #ifndef MAXPATHLEN
 #   ifdef PATH_MAX
 #       define MAXPATHLEN PATH_MAX
@@ -162,6 +183,10 @@
 #define SIGHUP  100
 #endif
 
+/* A few error types are used by Tcl that don't make sense on a Mac */
+/* They are defined here so that Tcl will compile with less modification */
+#define ECHILD	10
+
 extern char **environ;
 
 /*
@@ -179,15 +204,14 @@ double		hypot(double x, double y);
 #endif
 
 /*
- * The following declarations belong in tclInt.h, but depend on platform
- * specific types (e.g. struct tm).
+ * The following prototype and defines replace the Macintosh version
+ * of the ANSI functions localtime and gmtime.  The various compilier
+ * vendors to a simply horrible job of implementing these functions.
  */
-
-EXTERN struct tm *	TclpGetDate _ANSI_ARGS_((const time_t *tp,
-			    int useGMT));
-EXTERN size_t		TclStrftime _ANSI_ARGS_((char *s, size_t maxsize,
-			    const char *format, const struct tm *t));
-#define TclStrftime(s,m,f,t) (strftime((s),(m),(f),(t)))
+EXTERN struct tm * TclMacSecondsToDate _ANSI_ARGS_((const time_t *time,
+		    int useGMT));
+#define localtime(time) TclMacSecondsToDate(time, 0)
+#define gmtime(time) TclMacSecondsToDate(time, 1)
 
 /*
  * The following prototypes and defines replace the Macintosh version
@@ -202,8 +226,7 @@ EXTERN int TclMacAccess _ANSI_ARGS_((const char *filename, int mode));
 EXTERN FILE * TclMacFOpenHack _ANSI_ARGS_((const char *path,
 	const char *mode));
 #define fopen(path, mode) TclMacFOpenHack(path, mode)
-EXTERN int TclMacReadlink _ANSI_ARGS_((char *path, char *buf, int size));
-#define readlink(fileName, buffer, size) TclMacReadlink(fileName, buffer, size)
+#define readlink(fileName, buffer, size) -1
 
 /*
  * Defines for Tcl internal commands that aren't really needed on
