@@ -10,7 +10,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * SCCS: @(#) tclMacUtil.c 1.45 96/08/01 18:03:11
+ * SCCS: @(#) tclMacUtil.c 1.43 96/03/30 14:54:55
  */
 
 #include "tcl.h"
@@ -58,9 +58,7 @@
  *----------------------------------------------------------------------
  */
  
-#if defined(THINK_C) || GENERATING68K
-double hypot(double x, double y);
-
+#if defined(THINK_C)
 double
 hypot(x, y)
     double x, y;
@@ -125,7 +123,7 @@ TclMacEvalResource(interp, resourceName, resourceNumber, fileName)
 	    return TCL_ERROR;
 	}
 		
-	fileRef = FSpOpenResFileCompat(&fileSpec, fsRdPerm);
+	fileRef = FSpOpenResFile(&fileSpec, fsRdPerm);
 	if (fileRef == -1) {
 	    Tcl_AppendResult(interp, "Error reading the file: \"", 
 		fileName, "\".", NULL);
