@@ -9,7 +9,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * SCCS: @(#) tclWinChan.c 1.57 96/05/27 15:21:02
+ * SCCS: @(#) tclWinChan.c 1.51 96/04/12 17:06:06
  */
 
 #include	"tclInt.h"	/* Internal definitions for Tcl. */
@@ -337,37 +337,22 @@ FileClose(instanceData, interp, inFile, outFile)
 	}
         Tcl_FreeFile(inFile);
 
-        if (tclInInterpreterDeletion) {
-            if ((handle != GetStdHandle(STD_INPUT_HANDLE)) &&
-                    (handle != GetStdHandle(STD_OUTPUT_HANDLE)) &&
-                    (handle != GetStdHandle(STD_ERROR_HANDLE))) {
-                if (CloseHandle(handle) == FALSE) {
-                    TclWinConvertError(GetLastError());
-                    errorCode = errno;
-                }
-            }
-        } else if (CloseHandle(handle) == FALSE) {
-            TclWinConvertError(GetLastError());
-            errorCode = errno;
-        }
+	if (CloseHandle(handle) == FALSE) {
+	    TclWinConvertError(GetLastError());
+	    errorCode = errno;
+	}
+
     }
     if (outFile != NULL) {
         handle = (HANDLE) Tcl_GetFileInfo(outFile, &type);
 	Tcl_FreeFile(outFile);
 
-        if (tclInInterpreterDeletion) {
-            if ((handle != GetStdHandle(STD_INPUT_HANDLE)) &&
-                    (handle != GetStdHandle(STD_OUTPUT_HANDLE)) &&
-                    (handle != GetStdHandle(STD_ERROR_HANDLE))) {
-                if (CloseHandle(handle) == FALSE) {
-                    TclWinConvertError(GetLastError());
-                    errorCode = errno;
-                }
-            }
-        } else if (CloseHandle(handle) == FALSE) {
-            TclWinConvertError(GetLastError());
-            errorCode = errno;
-        }
+	if (CloseHandle(handle) == FALSE) {
+	    TclWinConvertError(GetLastError());
+	    if (errorCode == 0) {
+		errorCode = errno;
+	    }
+	}
     }
     return errorCode;
 }
@@ -768,11 +753,10 @@ Tcl_MakeFileChannel(inFile, outFile, mode)
                                  * TCL_WRITABLE to indicate whether inFile
                                  * and/or outFile are valid. */
 {
-    Tcl_Channel chan;
-    int fileUsed;
     Tcl_File inFd, outFd;
     char channelName[20];
     FileState *sPtr;
+    Tcl_Channel chan;
 
     if (mode & TCL_READABLE) {
         sprintf(channelName, "file%d", (int) inFile);
@@ -780,7 +764,7 @@ Tcl_MakeFileChannel(inFile, outFile, mode)
     } else {
         inFd = (Tcl_File) NULL;
     }
-
+    
     if (mode & TCL_WRITABLE) {
         sprintf(channelName, "file%d", (int) outFile);
         outFd = Tcl_GetFile(outFile, FileType((HANDLE) outFile));
@@ -788,26 +772,6 @@ Tcl_MakeFileChannel(inFile, outFile, mode)
         outFd = (Tcl_File) NULL;
     }
 
-    /*
-     * See if a channel with the right Tcl_Files in it already exists. If
-     * so, return it.
-     */
-    
-    chan = TclFindFileChannel(inFd, outFd, &fileUsed);
-    if (chan != (Tcl_Channel) NULL) {
-        return chan;
-    }
-
-    /*
-     * If one of the Tcl_Files is already used by another channel, do not
-     * create a new channel containing it. This will avoid core dumps later
-     * when the Tcl_File would be freed twice.
-     */
-
-    if (fileUsed) {
-        return (Tcl_Channel) NULL;
-    }
-
     sPtr = (FileState *) ckalloc((unsigned) sizeof(FileState));
     sPtr->asynch = 0;
     sPtr->append = 0;
@@ -820,7 +784,8 @@ Tcl_MakeFileChannel(inFile, outFile, mode)
     }
 
     /*
-     * Windows files have AUTO translation mode and ^Z eof char on input.
+     * Windows files have AUTO translation mode and ^Z eof char, which
+     * means that ^Z will be appended on close and accepted as EOF.
      */
     
     if (Tcl_SetChannelOption((Tcl_Interp *) NULL, chan, "-translation",
