@@ -11,7 +11,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * SCCS: @(#) tclWinFile.c 1.35 96/05/28 14:00:26
+ * SCCS: @(#) tclWinFile.c 1.34 96/04/15 18:28:13
  */
 
 #include <sys/stat.h>
@@ -632,6 +632,37 @@ TclMatchFiles(interp, separators, dirPtr, pattern, tail)
     return result;
 }
 
+/*
+ *----------------------------------------------------------------------
+ *
+ * TclGetStdHandles --
+ *
+ *	This function returns the file handles for standard I/O.
+ *
+ * Results:
+ *	Sets the arguments to the standard file handles.
+ *
+ * Side effects:
+ *	None.
+ *
+ *----------------------------------------------------------------------
+ */
+
+void
+TclGetStdHandles(stdinPtr, stdoutPtr, stderrPtr)
+    Tcl_File *stdinPtr;
+    Tcl_File *stdoutPtr;
+    Tcl_File *stderrPtr;
+{
+    HANDLE hStdInput = GetStdHandle(STD_INPUT_HANDLE);
+    HANDLE hStdOutput = GetStdHandle(STD_OUTPUT_HANDLE);
+    HANDLE hStdError = GetStdHandle(STD_ERROR_HANDLE);
+
+    *stdinPtr = Tcl_GetFile((ClientData) hStdInput, TCL_WIN_FILE);
+    *stdoutPtr = Tcl_GetFile((ClientData) hStdOutput, TCL_WIN_FILE);
+    *stderrPtr = Tcl_GetFile((ClientData) hStdError, TCL_WIN_FILE);
+}
+
 /*
  *----------------------------------------------------------------------
  *
